@@ -10,13 +10,19 @@ DBIx::Class::Schema::Versioned::Inline
 
 Schema versioning for DBIx::Class with version information embedded inline in the schema definition.
 
+=head1 WARNING
+
+Although all documented functionality has been implemented it is only possible to use the module currently with MySQL. Tests exist for SQLite and PostgreSQL but upgrade tests are currently broken and so are skipped due to issues with L<SQL::Translator>. I am hoping the SQLT issues can be resolved ASAP.
+
+This is BETA software so the usual caveats apply.
+
 =head1 VERSION
 
-Version 0.004
+Version 0.010
 
 =cut
 
-our $VERSION = '0.004';
+our $VERSION = '0.010';
 
 =head1 SYNOPSIS
 
@@ -270,7 +276,7 @@ Many methods are inherited or overloaded from L<DBIx::Class::Schema::Versioned>.
 
 =head2 connection
 
-Overloaded method. This checks the DBIC schema version against the DB version and ???? TODO ???? (undecided so far) if they are not the same or if the DB is unversioned.
+Overloaded method. This checks the DBIC schema version against the DB version and uses the DB version if it exists or the schema version if the database is currently unversioned.
 
 =cut
 
@@ -278,8 +284,8 @@ sub connection {
     my $self = shift;
     $self->next::method(@_);
 
-    my $conn_info = $self->storage->connect_info;
-    $self->{vschema} = DBIx::Class::Version->connect(@$conn_info);
+    my $connect_info = $self->storage->connect_info;
+    $self->{vschema} = DBIx::Class::Version->connect(@$connect_info);
     my $conn_attrs = $self->{vschema}->storage->_dbic_connect_attributes || {};
 
     my $vtable = $self->{vschema}->resultset('Table');
@@ -375,12 +381,14 @@ sub upgrade_single_step {
 
     my $sqlt_type = $self->storage->sqlt_type;
 
-    # add Upgrade versions
+    # add Upgrade before/after subs
+
     my $upgradeclass = ref($self) . "::Upgrade";
-    my @before_upgrade_subs;
+    my ( @before_upgrade_subs, @after_upgrade_subs );
     eval {
         eval "require $upgradeclass" or return;
         @before_upgrade_subs = $upgradeclass->before_upgrade($target_version);
+        @after_upgrade_subs  = $upgradeclass->after_upgrade($target_version);
     };
 
     # translate current schema
@@ -478,6 +486,10 @@ sub upgrade_single_step {
                         }
                     );
                 }
+                # 'after' steps use $target_schema
+                foreach my $sub (@after_upgrade_subs) {
+                    $sub->($target_schema) or die;
+                }
             }
         );
     }
@@ -679,9 +691,7 @@ Slaven Rezić (eserte)
 
 =head1 BUGS
 
-LOTS of bugs and missing features right now.
-
-NOTE: upgrades are NOT yet implemented.
+This is BETA software so bugs and missing features are expected.
 
 Please report any bugs or feature requests via the project's GitHub issue tracker:
 
